@@ -1,4 +1,4 @@
 library(drfit)
 data(pyrithione)
 rpyr <- drfit(pyrithione,linlogit=TRUE,linlogitWrong=c("MSPT","MSPHI"))
-rpyr
+print(rpyr,digits=3)
